[llvm-commits] CVS: llvm/include/llvm/Analysis/InductionVariable.h

Michael Brukman brukman at cs.uiuc.edu
Fri Oct 11 00:35:06 PDT 2002


Changes in directory llvm/include/llvm/Analysis:

InductionVariable.h updated: 1.4 -> 1.5

---
Log message:

Added capability to get execution count of a loop if it is a predictable
number of iterations.


---
Diffs of the changes:

Index: llvm/include/llvm/Analysis/InductionVariable.h
diff -u llvm/include/llvm/Analysis/InductionVariable.h:1.4 llvm/include/llvm/Analysis/InductionVariable.h:1.5
--- llvm/include/llvm/Analysis/InductionVariable.h:1.4	Fri Jul 26 20:11:59 2002
+++ llvm/include/llvm/Analysis/InductionVariable.h	Fri Oct 11 00:34:32 2002
@@ -34,7 +34,7 @@
     Unknown,                 // Unknown type.  Start & Step are null
   } InductionType;
   
-  Value *Start, *Step;       // Start and step expressions for this indvar
+  Value *Start, *Step, *End; // Start, step, and end expressions for this indvar
   PHINode *Phi;              // The PHI node that corresponds to this indvar
 public:
 
@@ -46,6 +46,9 @@
   // Classify Induction
   static enum iType Classify(const Value *Start, const Value *Step,
 			     const Loop *L = 0);
+
+  // Get number of times this loop will execute. Returns NULL if unpredictable.
+  Value* getExecutionCount(LoopInfo *LoopInfo);
 
   void print(std::ostream &OS) const;
 };





More information about the llvm-commits mailing list